@@ -3,7 +3,7 @@
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Xmobar.Plugins.Monitors
--- Copyright   :  (c) 2010, 2011, 2012, 2013, 2017, 2018, 2019 Jose Antonio Ortega Ruiz
+-- Copyright   :  (c) 2010-2013, 2017-2020, 2022 Jose Antonio Ortega Ruiz
 --                (c) 2007-10 Andrea Rossato
 -- License     :  BSD-style (see LICENSE)
 --
@@ -30,11 +30,13 @@ import Xmobar.Plugins.Monitors.Cpu
 import Xmobar.Plugins.Monitors.MultiCpu
 import Xmobar.Plugins.Monitors.Batt
 import Xmobar.Plugins.Monitors.Bright
+import Xmobar.Plugins.Monitors.Load
 import Xmobar.Plugins.Monitors.Thermal
 import Xmobar.Plugins.Monitors.ThermalZone
 import Xmobar.Plugins.Monitors.CpuFreq
 import Xmobar.Plugins.Monitors.CoreTemp
 import Xmobar.Plugins.Monitors.MultiCoreTemp
+import Xmobar.Plugins.Monitors.K10Temp
 import Xmobar.Plugins.Monitors.Disk
 import Xmobar.Plugins.Monitors.Top
 import Xmobar.Plugins.Monitors.Uptime
@@ -64,6 +66,7 @@ data Monitors = Network      Interface   Args Rate
               | Battery      Args        Rate
               | DiskU        DiskSpec    Args Rate
               | DiskIO       DiskSpec    Args Rate
+              | Load         Args        Rate
               | Thermal      Zone        Args Rate
               | ThermalZone  ZoneNo      Args Rate
               | Memory       Args        Rate
@@ -74,6 +77,7 @@ data Monitors = Network      Interface   Args Rate
               | CpuFreq      Args        Rate
               | CoreTemp     Args        Rate
               | MultiCoreTemp Args       Rate
+              | K10Temp      Slot        Args Rate
               | TopProc      Args        Rate
               | TopMem       Args        Rate
               | Uptime       Args        Rate
@@ -89,7 +93,8 @@ data Monitors = Network      Interface   Args Rate
               | Wireless Interface  Args Rate
 #endif
 #ifdef LIBMPD
-              | MPD      Args       Rate
+              | MPD Args Rate
+              | MPDX Args Rate Alias
               | AutoMPD  Args
 #endif
 #ifdef ALSA
@@ -112,6 +117,7 @@ type ZoneNo    = Int
 type Interface = String
 type Rate      = Int
 type DiskSpec  = [(String, String)]
+type Slot      = String
 
 instance Exec Monitors where
 #ifdef WEATHER
@@ -120,6 +126,7 @@ instance Exec Monitors where
 #endif
     alias (Network i _ _) = i
     alias (DynNetwork _ _) = "dynnetwork"
+    alias (Load _ _) = "load"
     alias (Thermal z _ _) = z
     alias (ThermalZone z _ _) = "thermal" ++ show z
     alias (Memory _ _) = "memory"
@@ -135,6 +142,7 @@ instance Exec Monitors where
     alias (TopMem _ _) = "topmem"
     alias (CoreTemp _ _) = "coretemp"
     alias (MultiCoreTemp _ _) = "multicoretemp"
+    alias K10Temp {} = "k10temp"
     alias DiskU {} = "disku"
     alias DiskIO {} = "diskio"
     alias (Uptime _ _) = "uptime"
@@ -148,6 +156,7 @@ instance Exec Monitors where
 #ifdef LIBMPD
     alias (MPD _ _) = "mpd"
     alias (AutoMPD _) = "autompd"
+    alias (MPDX _ _ a) = a
 #endif
 #ifdef ALSA
     alias (Volume m c _ _) = m ++ ":" ++ c
@@ -170,6 +179,7 @@ instance Exec Monitors where
     start (Thermal z a r) = runM (a ++ [z]) thermalConfig runThermal r
     start (ThermalZone z a r) =
       runM (a ++ [show z]) thermalZoneConfig runThermalZone r
+    start (Load a r) = runM a loadConfig runLoad r
     start (Memory a r) = runM a memConfig runMem r
     start (Swap a r) = runM a swapConfig runSwap r
     start (Battery a r) = runM a battConfig runBatt r
@@ -179,6 +189,7 @@ instance Exec Monitors where
     start (CpuFreq a r) = runM a cpuFreqConfig runCpuFreq r
     start (CoreTemp a r) = runM a coreTempConfig runCoreTemp r
     start (MultiCoreTemp a r) = startMultiCoreTemp a r
+    start (K10Temp s a r) = runM (a ++ [s]) k10TempConfig runK10Temp r
     start (DiskU s a r) = runM a diskUConfig (runDiskU s) r
     start (DiskIO s a r) = startDiskIO s a r
     start (Uptime a r) = runM a uptimeConfig runUptime r
@@ -191,6 +202,7 @@ instance Exec Monitors where
 #endif
 #ifdef LIBMPD
     start (MPD a r) = runMD a mpdConfig runMPD r mpdReady
+    start (MPDX a r _) = start (MPD a r)
     start (AutoMPD a) = runMBD a mpdConfig runMPD mpdWait mpdReady
 #endif
 #ifdef ALSA
