@@ -1,3 +1,4 @@
+{-#LANGUAGE CPP #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Plugins.Monitors.Mem
@@ -12,16 +13,23 @@
 --
 -----------------------------------------------------------------------------
 
-module Xmobar.Plugins.Monitors.Mem (memConfig, runMem, totalMem, usedMem) where
+module Xmobar.Plugins.Monitors.Mem (memConfig, runMem) where
 
 import Xmobar.Plugins.Monitors.Common
-import qualified Data.Map as M
 import System.Console.GetOpt
 
+#if defined(freebsd_HOST_OS)
+import qualified Xmobar.Plugins.Monitors.Mem.FreeBSD as MM
+#else
+import qualified Xmobar.Plugins.Monitors.Mem.Linux as MM
+#endif
+
+
 data MemOpts = MemOpts
   { usedIconPattern :: Maybe IconPattern
   , freeIconPattern :: Maybe IconPattern
   , availableIconPattern :: Maybe IconPattern
+  , scale :: Float
   }
 
 defaultOpts :: MemOpts
@@ -29,6 +37,7 @@ defaultOpts = MemOpts
   { usedIconPattern = Nothing
   , freeIconPattern = Nothing
   , availableIconPattern = Nothing
+  , scale = 1.0
   }
 
 options :: [OptDescr (MemOpts -> MemOpts)]
@@ -39,52 +48,34 @@ options =
      o { freeIconPattern = Just $ parseIconPattern x }) "") ""
   , Option "" ["available-icon-pattern"] (ReqArg (\x o ->
      o { availableIconPattern = Just $ parseIconPattern x }) "") ""
+  , Option "" ["scale"] (ReqArg (\x o -> o { scale = read x }) "") ""
   ]
 
 memConfig :: IO MConfig
 memConfig = mkMConfig
-       "Mem: <usedratio>% (<cache>M)" -- template
+       "Mem: <usedratio>% (<cache>M)"
        ["usedbar", "usedvbar", "usedipat", "freebar", "freevbar", "freeipat",
         "availablebar", "availablevbar", "availableipat",
         "usedratio", "freeratio", "availableratio",
-        "total", "free", "buffer", "cache", "available", "used"] -- available replacements
-
-fileMEM :: IO String
-fileMEM = readFile "/proc/meminfo"
-
-parseMEM :: IO [Float]
-parseMEM =
-    do file <- fileMEM
-       let content = map words $ take 8 $ lines file
-           info = M.fromList $ map (\line -> (head line, (read $ line !! 1 :: Float) / 1024)) content
-           [total, free, buffer, cache] = map (info M.!) ["MemTotal:", "MemFree:", "Buffers:", "Cached:"]
-           available = M.findWithDefault (free + buffer + cache) "MemAvailable:" info
-           used = total - available
-           usedratio = used / total
-           freeratio = free / total
-           availableratio = available / total
-       return [usedratio, freeratio, availableratio, total, free, buffer, cache, available, used]
-
-totalMem :: IO Float
-totalMem = fmap ((*1024) . (!!1)) parseMEM
-
-usedMem :: IO Float
-usedMem = fmap ((*1024) . (!!6)) parseMEM
+        "total", "free", "buffer", "cache", "available", "used"]
 
 formatMem :: MemOpts -> [Float] -> Monitor [String]
 formatMem opts (r:fr:ar:xs) =
-    do let f = showDigits 0
-           mon i x = [showPercentBar (100 * x) x, showVerticalBar (100 * x) x, showIconPattern i x]
+    do d <- getConfigValue decDigits
+       let f = showDigits d
+           mon i x = [ showPercentBar (100 * x) x
+                     , showVerticalBar (100 * x) x
+                     , showIconPattern i x]
        sequence $ mon (usedIconPattern opts) r
            ++ mon (freeIconPattern opts) fr
            ++ mon (availableIconPattern opts) ar
            ++ map showPercentWithColors [r, fr, ar]
-           ++ map (showWithColors f) xs
+           ++ map (showWithColors f . (/ scale opts)) xs
 formatMem _ _ = replicate 10 `fmap` getConfigValue naString
 
 runMem :: [String] -> Monitor String
 runMem argv =
-    do m <- io parseMEM
+    do m <- io MM.parseMEM
        opts <- io $ parseOptsWith options defaultOpts argv
        l <- formatMem opts m
        parseTemplate l
